diff mbox series

[U-Boot] fs-test.sh: Update to use 'host' not 'sb'

Message ID 1543253958-31652-1-git-send-email-trini@konsulko.com
State Accepted
Commit 734e207c5e3ced07f4077ad46460d52912374f2a
Delegated to: Tom Rini
Headers show
Series [U-Boot] fs-test.sh: Update to use 'host' not 'sb' | expand

Commit Message

Tom Rini Nov. 26, 2018, 5:39 p.m. UTC
For a long time now, 'sb' has been deprecated as a command in favor of
using 'host' for the sandbox hostfs interface, switch.

Signed-off-by: Tom Rini <trini@konsulko.com>
---
 test/fs/fs-test.sh | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

Comments

Tom Rini Nov. 26, 2018, 6:44 p.m. UTC | #1
On Mon, Nov 26, 2018 at 12:39:18PM -0500, Tom Rini wrote:

> For a long time now, 'sb' has been deprecated as a command in favor of
> using 'host' for the sandbox hostfs interface, switch.
> 
> Signed-off-by: Tom Rini <trini@konsulko.com>

Applied to u-boot/master, thanks!
diff mbox series

Patch

diff --git a/test/fs/fs-test.sh b/test/fs/fs-test.sh
index 86308cfe2dbd..721af71d44ca 100755
--- a/test/fs/fs-test.sh
+++ b/test/fs/fs-test.sh
@@ -194,7 +194,7 @@  function test_image() {
 		;;
 
 		sb)
-		PREFIX="sb "
+		PREFIX="host "
 		WRITE="save"
 		SUFFIX="fs -"
 		;;
@@ -217,11 +217,11 @@  function test_image() {
 
 	# In u-boot commands, <interface> stands for host or hostfs
 	# hostfs maps to the host fs.
-	# host maps to the "sb bind" that we do
+	# host maps to the "host bind" that we do
 
 	$UBOOT << EOF
 sb=$5
-setenv bind 'if test "\$sb" != sb; then sb bind 0 "$1"; fi'
+setenv bind 'if test "\$sb" != sb; then host bind 0 "$1"; fi'
 run bind
 # Test Case 1 - ls
 ${PREFIX}ls host${SUFFIX} $6
@@ -229,7 +229,7 @@  ${PREFIX}ls host${SUFFIX} $6
 ${PREFIX}ls host${SUFFIX} invalid_d
 #
 # We want ${PREFIX}size host 0:0 $3 for host commands and
 # sb size hostfs - $3 for hostfs commands.
 # 1MB is 0x0010 0000
 # Test Case 2a - size of small file
 ${PREFIX}size host${SUFFIX} ${FPATH}$FILE_SMALL
@@ -575,7 +575,7 @@  TOTAL_PASS=0
 
 # In each loop, for a given file system image, we test both the
 # fs command, like load/size/write, the file system specific command
 # like: ext4load/ext4size/ext4write and the sb load/ls/save commands.
 for fs in ext4 fat16 fat32; do
 
 	echo "Creating $fs image if not already present."
@@ -583,11 +583,11 @@  for fs in ext4 fat16 fat32; do
 	MD5_FILE_FS="${MD5_FILE}.${fs}"
 	create_image $IMAGE $fs
 
 	# sb commands test
 	echo "Creating files in $fs image if not already present."
 	create_files $IMAGE $MD5_FILE_FS
 
 	# Lets mount the image and test sb hostfs commands
 	mkdir -p "$MOUNT_DIR"
 	case "$fs" in
 		fat*)
@@ -229,7 +229,7 @@  ${PREFIX}ls host${SUFFIX} $6
 #
 # We want ${PREFIX}size host 0:0 $3 for host commands and
-# sb size hostfs - $3 for hostfs commands.
+# host size hostfs - $3 for hostfs commands.
 # 1MB is 0x0010 0000
 # Test Case 2a - size of small file
@@ -575,7 +575,7 @@  TOTAL_PASS=0
 # In each loop, for a given file system image, we test both the
 # fs command, like load/size/write, the file system specific command
-# like: ext4load/ext4size/ext4write and the sb load/ls/save commands.
+# like: ext4load/ext4size/ext4write and the host load/ls/save commands.
 for fs in ext4 fat16 fat32; do
 
@@ -583,11 +583,11 @@  for fs in ext4 fat16 fat32; do
 	create_image $IMAGE $fs
 
-	# sb commands test
+	# host commands test
 	echo "Creating files in $fs image if not already present."
 	create_files $IMAGE $MD5_FILE_FS
@@ -583,11 +583,11 @@  for fs in ext4 fat16 fat32; do
 	create_files $IMAGE $MD5_FILE_FS
 
-	# Lets mount the image and test sb hostfs commands
+	# Lets mount the image and test host hostfs commands
 	mkdir -p "$MOUNT_DIR"
 	case "$fs" in